==> zio-aws-pinpoint_3-5.17.104.12-sources.jar: zio/aws/pinpoint/model/GetCampaignActivitiesRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import scala.jdk.CollectionConverters.*
final case class GetCampaignActivitiesRequest(
    applicationId: __string,
    campaignId: __string,
    pageSize: Option[__string] = None,
    token: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest = {
    import GetCampaignActivitiesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .campaignId(__string.unwrap(campaignId): java.lang.String)
      .optionallyWith(
        pageSize.map(value => __string.unwrap(value): java.lang.String)
      )(_.pageSize)
      .optionallyWith(
        token.map(value => __string.unwrap(value): java.lang.String)
      )(_.token)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignActivitiesRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignActivitiesRequest.wrap(buildAwsValue())
}
object GetCampaignActivitiesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignActivitiesRequest =
      zio.aws.pinpoint.model.GetCampaignActivitiesRequest(
        applicationId,
        campaignId,
        pageSize.map(value => value),
        token.map(value => value)
      )
    def applicationId: __string
    def campaignId: __string
    def pageSize: Option[__string]
    def token: Option[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getCampaignId: ZIO[Any, Nothing, __string] = ZIO.succeed(campaignId)
    def getPageSize: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("token", token)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
  ) extends zio.aws.pinpoint.model.GetCampaignActivitiesRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.applicationId())
    override val campaignId: __string =
      zio.aws.pinpoint.model.primitives.__string(impl.campaignId())
    override val pageSize: Option[__string] = scala
      .Option(impl.pageSize())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
    override val token: Option[__string] = scala
      .Option(impl.token())
      .map(value => zio.aws.pinpoint.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
  ): zio.aws.pinpoint.model.GetCampaignActivitiesRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-pinpoint_3-6.20.78.3-sources.jar: zio/aws/pinpoint/model/GetCampaignActivitiesRequest.scala <==
package zio.aws.pinpoint.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.pinpoint.model.primitives.__string
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class GetCampaignActivitiesRequest(
    applicationId: __string,
    campaignId: __string,
    pageSize: Optional[__string] = Optional.Absent,
    token: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest = {
    import GetCampaignActivitiesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .campaignId(campaignId: java.lang.String)
      .optionallyWith(pageSize.map(value => value: java.lang.String))(
        _.pageSize
      )
      .optionallyWith(token.map(value => value: java.lang.String))(_.token)
      .build()
  }
  def asReadOnly: zio.aws.pinpoint.model.GetCampaignActivitiesRequest.ReadOnly =
    zio.aws.pinpoint.model.GetCampaignActivitiesRequest.wrap(buildAwsValue())
}
object GetCampaignActivitiesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.pinpoint.model.GetCampaignActivitiesRequest =
      zio.aws.pinpoint.model.GetCampaignActivitiesRequest(
        applicationId,
        campaignId,
        pageSize.map(value => value),
        token.map(value => value)
      )
    def applicationId: __string
    def campaignId: __string
    def pageSize: Optional[__string]
    def token: Optional[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getCampaignId: ZIO[Any, Nothing, __string] = ZIO.succeed(campaignId)
    def getPageSize: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("pageSize", pageSize)
    def getToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("token", token)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
  ) extends zio.aws.pinpoint.model.GetCampaignActivitiesRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val campaignId: __string = impl.campaignId(): __string
    override val pageSize: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.pageSize())
      .map(value => value: __string)
    override val token: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.token())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.pinpoint.model.GetCampaignActivitiesRequest
  ): zio.aws.pinpoint.model.GetCampaignActivitiesRequest.ReadOnly = new Wrapper(
    impl
  )
}
